# Unidades de tamanho
KILOBYTE = 1024
MEGABYTE = 1024 * 1024
GIGABYTE = 1024 * 1024 * 1024
TERABYTE = 1024 * 1024 * 1024 * 1024

# Unidades de tempo
MILLISECONDS = 0.001
SECONDS = 1
MINUTES = 60 * SECONDS
HOURS = 60 * MINUTES



from .config import setup_logging
from .filters import ExcludeLoggerFilter, RequestIdFilter
from .formatters import FORMATTERS, JsonFormatter
from .handlers import HANDLERS

__all__ = ["FORMATTERS", "HANDLERS", "ExcludeLoggerFilter", "RequestIdFilter", "JsonFormatter", "setup_logging"]
